@@ -215,7 +215,7 @@ case "$switch" in
      rm -f /etc/rcS.d/*Forcevideo-drbl-live 
 
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
-     . $drbl_setup_path/files/ocs/live-hook/ocs-live.conf
+     . $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
 
      # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
      yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi -p $client_no_per_NIC
